==> fred-prequel-0.1.0.tar.gz: fred-prequel-0.1.0/prequel/common.py <==
"""Public request common classes and utils."""
import warnings
from datetime import datetime
from enum import Enum, unique
from typing import Callable, Iterable, Optional

from pydantic import BaseModel, Field, root_validator

from .exceptions import ExtraArgumentWarning


class _BaseModel(BaseModel):
    """Base model for all prequel models."""

    @root_validator(pre=True)
    def _warn_extra(cls, values: dict) -> dict:
        """Emit warnings for any extra arguments passed to model."""
        for field in values.keys() - cls.__fields__.keys():
            msg = "Unexpected extra argument {} for model {}.{}".format(
                field, cls.__module__, cls.__name__  # type: ignore
            )
            warnings.warn(msg, ExtraArgumentWarning, stacklevel=2)
        return values


class BaseId(str):
    """Identifier base class - always represented as string."""

    @classmethod
    def __get_validators__(cls) -> Iterable[Callable]:
        yield cls._validate

    @classmethod
    def _validate(cls, value: str) -> "BaseId":
        return cls(value)

    def __repr__(self) -> str:
        return "{}({})".format(self.__class__.__name__, super().__repr__())


@unique
class ObjectType(str, Enum):
    """Object type enumeration."""

    CONTACT = "contact"
    DOMAIN = "domain"
    KEYSET = "keyset"
    NSSET = "nsset"


class ObjectId(_BaseModel):
    """Object identification - type and unique name."""

    type: ObjectType
    value: str = Field(..., min_length=1)  # required item


@unique
class RequestStatus(str, Enum):
    """Public request processing status."""

    OPEN = "open"
    RESOLVED = "resolved"
    INVALIDATED = "invalidated"


@unique
class RequestOnStatusAction(str, Enum):
    """Public request action status."""

    SCHEDULED = "scheduled"
    PROCESSED = "processed"
    FAILED = "failed"


class PublicRequest(_BaseModel):
    """Public request info.

    Attributes:
        public_request_id: unique identifier of public request
        numeric_id: unique identifier of public request (db index)
        object_id: type (domain, ...) and unique name of linked object
        type: public request type (same as PublicRequestType.name)
        registrar_id: sponsoring registrar holding linked object
        response_email: contact for receiving request resolution answer
        create_time: time and log item of request creation
        creation_id: log item of request creation
        resolve_time: time of request resolution
        resolving_id: log item of request resolution
        status: request resolution status
        on_status_action: request processing status
    """

    public_request_id: str = Field(..., min_length=1)  # required item
    numeric_id: int
    object_id: ObjectId
    type: str
    registrar_id: Optional[str] = None
    response_email: Optional[str] = None
    create_time: datetime
    creation_id: Optional[str] = None
    resolve_time: Optional[datetime] = None
    resolving_id: Optional[str] = None
    status: RequestStatus
    on_status_action: RequestOnStatusAction

==> fred-prequel-0.2.1.tar.gz: fred-prequel-0.2.1/prequel/common.py <==
"""Public request common classes and utils."""
import warnings
from datetime import datetime
from enum import Enum, unique
from typing import Callable, Iterable, Optional

from pydantic import BaseModel, Field, root_validator

from .exceptions import ExtraArgumentWarning


class _BaseModel(BaseModel):
    """Base model for all prequel models."""

    @root_validator(pre=True)
    def _warn_extra(cls, values: dict) -> dict:
        """Emit warnings for any extra arguments passed to model."""
        for field in values.keys() - cls.__fields__.keys():
            msg = "Unexpected extra argument {} for model {}.{}".format(
                field, cls.__module__, cls.__name__  # type: ignore
            )
            warnings.warn(msg, ExtraArgumentWarning, stacklevel=2)
        return values


class BaseId(str):
    """Identifier base class - always represented as non-empty string."""

    @classmethod
    def __get_validators__(cls) -> Iterable[Callable]:
        yield cls._validate

    @classmethod
    def _validate(cls, value: str) -> "BaseId":
        if not value:
            raise ValueError("identifier must not be empty")
        return cls(value)

    def __repr__(self) -> str:
        return "{}({})".format(self.__class__.__name__, super().__repr__())


class PublicRequestId(BaseId):
    """Public request unique identifier."""


@unique
class RegistryObjectType(str, Enum):
    """Object type enumeration."""

    CONTACT = "contact"
    DOMAIN = "domain"
    KEYSET = "keyset"
    NSSET = "nsset"


class Reference(_BaseModel):
    """Object reference - type and unique identifier."""

    type: RegistryObjectType
    value: str = Field(..., min_length=1)


@unique
class RequestStatus(str, Enum):
    """Public request processing status."""

    OPEN = "open"
    RESOLVED = "resolved"
    INVALIDATED = "invalidated"


@unique
class RequestOnStatusAction(str, Enum):
    """Public request action status."""

    SCHEDULED = "scheduled"
    PROCESSED = "processed"
    FAILED = "failed"


class PublicRequest(_BaseModel):
    """Public request info.

    Attributes:
        public_request_id: unique identifier of public request
        numeric_id: unique identifier of public request (db index)
        reference: type (domain, ...) and unique identifier of referenced object
        type: public request type (same as PublicRequestType.name)
        registrar_id: sponsoring registrar holding linked object
        response_email: contact for receiving request resolution answer
        create_time: time and log item of request creation
        creation_id: log item of request creation
        resolve_time: time of request resolution
        resolving_id: log item of request resolution
        status: request resolution status
        on_status_action: request processing status
    """

    public_request_id: PublicRequestId
    numeric_id: int
    reference: Reference
    type: str
    registrar_id: Optional[str] = None
    response_email: Optional[str] = None
    create_time: datetime
    creation_id: Optional[str] = None
    resolve_time: Optional[datetime] = None
    resolving_id: Optional[str] = None
    status: RequestStatus
    on_status_action: RequestOnStatusAction
